History
-------

0.0.5 (2013-03-07)
++++++++++++++++++
- More detailed metadata handling.
- Only update if needed or forced.

0.0.4 (2013-03-03)
++++++++++++++++++
- Fix key names including the whole path.
- Add groundwork for defaulting the minifier dict.
- The update() helper method now takes an optional input directory.
- Add an example collect_static script.
- Sets the S3 ACL to allow public read access.
